aboutsummaryrefslogtreecommitdiff
path: root/pkg/machine/qemu/config.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2022-04-25 13:37:59 -0400
committerGitHub <noreply@github.com>2022-04-25 13:37:59 -0400
commita775e77cba3be5ec77738787f4346ff7e1d24462 (patch)
treef50573eb3d9c42aa89a93b0a15298a0909fb38fe /pkg/machine/qemu/config.go
parent9784d97bd6cef590de781575992f7a685ab1c2c2 (diff)
parenta615cb2fe22dbfb3ec0acc0e60d8f849301c3aac (diff)
downloadpodman-a775e77cba3be5ec77738787f4346ff7e1d24462.tar.gz
podman-a775e77cba3be5ec77738787f4346ff7e1d24462.tar.bz2
podman-a775e77cba3be5ec77738787f4346ff7e1d24462.zip
Merge pull request #13995 from ashley-cui/revrootful
Rootfull -> Rootful
Diffstat (limited to 'pkg/machine/qemu/config.go')
-rw-r--r--pkg/machine/qemu/config.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkg/machine/qemu/config.go b/pkg/machine/qemu/config.go
index e9416dc36..7340de604 100644
--- a/pkg/machine/qemu/config.go
+++ b/pkg/machine/qemu/config.go
@@ -57,8 +57,8 @@ type MachineVMV1 struct {
QMPMonitor Monitorv1
// RemoteUsername of the vm user
RemoteUsername string
- // Whether this machine should run in a rootfull or rootless manner
- Rootfull bool
+ // Whether this machine should run in a rootful or rootless manner
+ Rootful bool
// UID is the numerical id of the user that called machine
UID int
}
@@ -99,8 +99,8 @@ type ImageConfig struct {
// HostUser describes the host user
type HostUser struct {
- // Whether this machine should run in a rootfull or rootless manner
- Rootfull bool
+ // Whether this machine should run in a rootful or rootless manner
+ Rootful bool
// UID is the numerical id of the user that called machine
UID int
}